summaryrefslogtreecommitdiffstats
path: root/k8s-bootstrap-container/bootstrap.sh
diff options
context:
space:
mode:
authorwasala <przemyslaw.wasala@nokia.com>2018-09-19 13:51:36 +0200
committerwasala <przemyslaw.wasala@nokia.com>2018-09-24 08:06:15 +0200
commit42517301e671cc1ba96fc9e02de2985af57e9736 (patch)
tree96b04a14669597e6acad79c5828e8d49050c4a21 /k8s-bootstrap-container/bootstrap.sh
parent20fdd615eeb9b4fa1594273b1fa3d7eca8992c8b (diff)
Added Datafile-Collector to deployment
Change-Id: Ic66a74b11490bcfcca92a7bb44762f1a1c6989ce Issue-ID: DCAEGEN2-784 Signed-off-by: wasala <przemyslaw.wasala@nokia.com>
Diffstat (limited to 'k8s-bootstrap-container/bootstrap.sh')
-rwxr-xr-xk8s-bootstrap-container/bootstrap.sh3
1 files changed, 2 insertions, 1 deletions
diff --git a/k8s-bootstrap-container/bootstrap.sh b/k8s-bootstrap-container/bootstrap.sh
index b4a05a7..a675ba8 100755
--- a/k8s-bootstrap-container/bootstrap.sh
+++ b/k8s-bootstrap-container/bootstrap.sh
@@ -217,12 +217,13 @@ PH_PID=$!
wait ${INV_PID} ${DH_PID} ${PH_PID}
# Deploy service components
# tca, ves, prh, hv-ves can be deployed simultaneously
deploy tca k8s-tca.yaml k8s-tca-inputs.yaml &
deploy ves k8s-ves.yaml k8s-ves-inputs.yaml &
deploy snmptrap k8s-snmptrap.yaml k8s-snmptrap-inputs.yaml &
deploy prh k8s-prh.yaml k8s-prh-inputs.yaml &
deploy hv-ves k8s-hv-ves.yaml k8s-hv_ves-inputs.yaml &
+deploy datafile-collector k8s-datafile-collector.yaml k8s-datafile-collector-input.yaml &
# holmes_rules must be deployed before holmes_engine, but holmes_rules can go in parallel with other service components
deploy holmes_rules k8s-holmes-rules.yaml k8s-holmes_rules-inputs.yaml
deploy holmes_engine k8s-holmes-engine.yaml k8s-holmes_engine-inputs.yaml
@@ -217,12 +217,13 @@ PH_PID=$!
wait ${INV_PID} ${DH_PID} ${PH_PID}
# Deploy service components
-# tca, ves, prh, hv-ves can be deployed simultaneously
+# tca, ves, prh, hv-ves, datafile-collector can be deployed simultaneously
deploy tca k8s-tca.yaml k8s-tca-inputs.yaml &
deploy ves k8s-ves.yaml k8s-ves-inputs.yaml &